package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesQueueOrderPushCellCfgService;
import cn.estsh.i3plus.ext.mes.pojo.util.MesExtConstWords;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesQueueOrderPushCellCfg;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@Slf4j
public class MesQueueOrderPushCellCfgService extends BaseMesService<MesQueueOrderPushCellCfg> implements IMesQueueOrderPushCellCfgService {

    @Override
    protected void setPackQueryBean(MesQueueOrderPushCellCfg bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getPushSourceCode(), MesExtConstWords.PUSH_SOURCE_CODE, packBean);
        DdlPreparedPack.getNumEqualPack(bean.getPushType(), MesExtConstWords.PUSH_TYPE, packBean);
        DdlPreparedPack.getStringEqualPack(bean.getAreaCode(), MesExtConstWords.AREA_CODE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getWorkCenterCode(), MesExtConstWords.WORK_CENTER_CODE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getWorkCellCode(), MesExtConstWords.WORK_CELL_CODE, packBean);
    }

    @Override
    protected void onInsertBean(MesQueueOrderPushCellCfg item) {
        ValidatorBean.checkNotNull(item.getAreaCode(), "区域代码不能为空");
        ValidatorBean.checkNotNull(item.getWorkCenterCode(), "生产线代码不能为空");
        ValidatorBean.checkNotNull(item.getWorkCellCode(), "工位代码不能为空");
        ValidatorBean.checkNotNull(item.getPushSourceCode(), "推送来源代码不能为空");
        ValidatorBean.checkNotNull(item.getPushType(), "推送工位类型不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPushSourceCode(), MesExtConstWords.PUSH_SOURCE_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getWorkCenterCode(), MesExtConstWords.WORK_CENTER_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getWorkCellCode(), MesExtConstWords.WORK_CELL_CODE, packBean);
        DdlPreparedPack.getNumEqualPack(item.getPushType(), MesExtConstWords.PUSH_TYPE, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("推送来源代码[%s]生产线代码[%s]工位代码[%s]类型[%s]信息已经存在，请检查数据",
                            item.getPushSourceCode(), item.getWorkCenterCode(), item.getWorkCellCode(), MesExtEnumUtil.QUEUE_ORDER_CELL_PUSH_TYPE.valueOfDescription(item.getPushType()))
                    .build();
        }
    }

    @Override
    protected void onUpdateBean(MesQueueOrderPushCellCfg item) {
        ValidatorBean.checkNotNull(item.getAreaCode(), "区域代码不能为空");
        ValidatorBean.checkNotNull(item.getWorkCenterCode(), "生产线代码不能为空");
        ValidatorBean.checkNotNull(item.getWorkCellCode(), "工位代码不能为空");
        ValidatorBean.checkNotNull(item.getPushSourceCode(), "推送来源代码不能为空");
        ValidatorBean.checkNotNull(item.getPushType(), "推送工位类型不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPushSourceCode(), MesExtConstWords.PUSH_SOURCE_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getWorkCenterCode(), MesExtConstWords.WORK_CENTER_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getWorkCellCode(), MesExtConstWords.WORK_CELL_CODE, packBean);
        DdlPreparedPack.getNumEqualPack(item.getPushType(), MesExtConstWords.PUSH_TYPE, packBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), MesExtConstWords.ID, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("推送来源代码[%s]生产线代码[%s]工位代码[%s]类型[%s]信息已经存在，请检查数据",
                            item.getPushSourceCode(), item.getWorkCenterCode(), item.getWorkCellCode(), MesExtEnumUtil.QUEUE_ORDER_CELL_PUSH_TYPE.valueOfDescription(item.getPushType()))
                    .build();
        }
    }

    @Override
    public List<MesQueueOrderPushCellCfg> validateReturnImport(List<MesQueueOrderPushCellCfg> beanList) {
        for (MesQueueOrderPushCellCfg item : beanList) {
            onInsertBean(item);
        }
        return  beanList;
    }

}
